@@ -182,12 +182,11 @@ static void ORBit_ORB_release(CORBA_ORB orb, CORBA_Environment *ev)
 	g_free(orb);
 }
 
-static GIOPConnection*
-ORBit_ORB_make_usock_connection(void)
+static void
+ORBit_make_local_tmpdir(void)
 {
-	GIOPConnection *retval = NULL;
-	GString *tmpstr;
 	struct stat statbuf;
+	GString *tmpstr;
 
 	tmpstr = g_string_new(NULL);
 
@@ -221,9 +220,21 @@ ORBit_ORB_make_usock_connection(void)
 	{
 		struct utimbuf utb;
 		memset(&utb, 0, sizeof(utb));
+		/* I think this is here to hide some information from somebody.
+		   I forgot exactly why. */
 		utime(tmpstr->str, &utb);
 	}
 
+	g_string_free(tmpstr, TRUE);
+}
+
+static GIOPConnection*
+ORBit_ORB_make_usock_connection(void)
+{
+	GIOPConnection *retval = NULL;
+	GString *tmpstr;
+
+	tmpstr = g_string_new(NULL);
 
 #ifdef WE_DONT_CARE_ABOUT_STUPID_2DOT0DOTX_KERNELS
 	g_string_sprintf(tmpstr, "/tmp/orbit-%s",
@@ -425,6 +436,8 @@ CORBA_ORB CORBA_ORB_init(int *argc, char **argv, CORBA_ORBid orb_identifier, COR
 		GIOP_CONNECTION(orb->cnx.ipv6)->orb_data = orb;
 	}
 
+	ORBit_make_local_tmpdir();
+
 	if(use_usock) {
 		orb->cnx.usock = ORBit_ORB_make_usock_connection();
 
